#! /bin/sh

# check ${installroot} 
# if it has value, current installation is running for stateless rootimage
# if it is null, current installation is running for a diskful node installation or updatenode

if [ -n "${installroot}" ]; then
       if [ \! -d ${installroot} ]; then
               echo "Install root defined to be ${installroot} but does not exist"
               exit 1
       fi
fi


rpmdir="${installroot}/opt/xcat/kits/<<<buildkit_WILL_INSERT_kit_basename_HERE>>>/<<<buildkit_WILL_INSERT_kitcomponent_name_HERE>>>"

if [ \! -d ${rpmdir} ]; then
       echo "Cannot find rpmdir ${rpmdir}, exiting"
       exit 1
fi


# check the source rpm packages for installing
OT=`ls $rpmdir/mpss* 2>/dev/null`
if [ $? -ne 0 ]; then
    exit 0
fi

# stop the mpssd before installing for non-rootimage install
if [ -z "${installroot}" ]; then
	if [ -x "/etc/init.d/mpss" ]; then
	    # stop the mpss service first
	    /etc/init.d/mpss unload
	fi
fi

# uninstall mpss before installing
if [ -x "/etc/init.d/mpss" ]; then
	# for mpss 2.x, run yum remove to uninstall mpss
	yum -y remove --noplugins --disablerepo=* intel-mic\*

	# for mpss 3.1, run yum to uninstall all possible mpss rpm package
	yum -y remove --noplugins --disablerepo=* mpss-sysmgmt-crashmgr mpss-sysmgmt-crashmgr-dev dapl-dbg libibscif-dbg libscif-dbg mpss-coi-dbg mpss-daemon-dbg mpss-ganglia-web-dbg mpss-myo-dbg mpss-sciftutorials-dbg ofed-all-dbg mpss-ganglia-web mpss-ganglia-web-dev glibc2.12.2pkg-libmicaccesssdk0 glibc2.12.2pkg-libmicaccesssdk-dev glibc2.12.2pkg-libmicaccesssdk-doc glibc2.12.2pkg-libmicmgmt0 glibc2.12.2pkg-libmicmgmt-dev glibc2.12.2pkg-libmicmgmt-doc glibc2.12.2pkg-libodmdebug0 glibc2.12.2pkg-libodmdebug-dev glibc2.12.2pkg-libsettings0 glibc2.12.2pkg-libsettings-dev intel-composerxe-compat-k1om libscif0 libscif-dev libscif-doc mpss-boot-files mpss-coi mpss-coi-dev mpss-coi-doc mpss-daemon mpss-daemon-dev mpss-eclipse-cdt-mpm mpss-flash mpss-license mpss-metadata mpss-metadata-dev mpss-miccheck mpss-miccheck-bin mpss-micmgmt mpss-micmgmt-doc mpss-micmgmt-python mpss-modules-headers mpss-modules-headers-dev mpss-mpm mpss-mpm-doc mpss-myo mpss-myo-dev mpss-myo-doc mpss-rasmm-kernel mpss-sciftutorials mpss-sciftutorials-doc mpss-sdk-k1om mpss-sysmgmt-micras mpss-sysmgmt-micsmc-gui mpss-sysmgmt-python dapl dapl-dev dapl-doc dapl-staticdev libibscif libibscif-dev libibscif-staticdev ofed-all ofed-all-dev ofed-ibpd ofed-ibpd-dev micperf micperf-data mpss-psm mpss-psm-dev ofed-driver ofed-driver-dbg-2.6.32-220.el6.x86_64 mpss-modules-2.6.32-220.el6.x86_64 mpss-modules-dev-2.6.32-220.el6.x86_64 ofed-driver-2.6.32-220.el6.x86_64 ofed-driver-2.6.32-220.el6.x86_64-devel ofed-driver-dev-2.6.32-220.el6.x86_64 mpss-modules
fi

# install the new packages
if [ ${installroot} ]; then
	yum -y install --installroot=${installroot} --nogpgcheck --noplugins --disablerepo=* $rpmdir/*.rpm
	chroot ${installroot} depmod -ae
else
	yum -y install --nogpgcheck --noplugins --disablerepo=* $rpmdir/*.rpm
fi

# enable the mpss service only for stateful host node
if [ -z "${installroot}" ]; then
	chkconfig mpss on
	#/etc/init.d/mpss start >/dev/null  2>&1 </dev/null
fi

if [ -z "${installroot}" ]; then
	# remove the rpm files to prevent the repeat installation by updatenode
	rm -rf $rpmdir/*
fi

echo "finished the mpss installation."
exit 0
